/*
 * Copyright (c) 2006-2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: GridPanel.java,v 1.6 2007/02/20 22:53:21 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.gui;

import java.util.List;

import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import edu.indiana.extreme.xbaya.util.SwingUtil;

/**
 * @author Satoshi Shirasuna
 */
public class GridPanel implements XBayaComponent {

    /**
     * Wight none of rows or eolumns. Used by layout().
     */
    public final static int WEIGHT_NONE = SwingUtil.WEIGHT_NONE;

    /**
     * Weight all rows or columns equally. Used by layout().
     */
    public final static int WEIGHT_EQUALLY = SwingUtil.WEIGHT_EQUALLY;

    private JPanel contentPanel;

    private JComponent rootComponent;

    /**
     * Constructs a GridPanel.
     */
    public GridPanel() {
        this(false);
    }

    /**
     * Constructs a GridPanel.
     * 
     * @param scroll
     *            true if scroll is needed; false otherwise.
     */
    public GridPanel(boolean scroll) {
        init(scroll);
    }

    /**
     * @see edu.indiana.extreme.xbaya.gui.XBayaComponent#getSwingComponent()
     */
    public JComponent getSwingComponent() {
        return this.rootComponent;
    }

    /**
     * @return The panel.
     */
    public JPanel getContentPanel() {
        return this.contentPanel;
    }

    /**
     * @param component
     */
    public void add(XBayaComponent component) {
        add(component.getSwingComponent());
    }

    /**
     * @param component
     * @param index
     */
    public void add(XBayaComponent component, int index) {
        add(component.getSwingComponent(), index);
    }

    /**
     * @param component
     */
    public void add(JComponent component) {
        this.contentPanel.add(component);
    }

    /**
     * @param component
     * @param index
     */
    public void add(JComponent component, int index) {
        this.contentPanel.add(component, index);
    }

    /**
     * @param index
     */
    public void remove(int index) {
        this.contentPanel.remove(index);
    }

    /**
     * Layouts the child components of a specified parent component using
     * GridBagLayout.
     * 
     * @param numRow
     *            The number of rows
     * @param numColumn
     *            The number of columns
     * @param weightedRow
     *            The row to weight
     * @param weightedColumn
     *            The column to weight
     */
    public void layout(int numRow, int numColumn, int weightedRow,
            int weightedColumn) {
        SwingUtil.layoutToGrid(this.contentPanel, numRow, numColumn,
                weightedRow, weightedColumn);
    }

    /**
     * @param rowWeights
     * @param columnWeights
     */
    public void layout(double[] rowWeights, double[] columnWeights) {
        SwingUtil.layoutToGrid(this.contentPanel, rowWeights, columnWeights);
    }

    /**
     * @param rowWeights
     * @param columnWeights
     */
    public void layout(List<Double> rowWeights, List<Double> columnWeights) {
        SwingUtil.layoutToGrid(this.contentPanel, rowWeights, columnWeights);
    }

    private void init(boolean scroll) {
        this.contentPanel = new JPanel();
        if (scroll) {
            this.contentPanel.setOpaque(true);
            JScrollPane scrollPane = new JScrollPane(this.contentPanel);
            this.rootComponent = scrollPane;
        } else {
            this.rootComponent = this.contentPanel;
        }
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2006-2007 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
